## 0.4.0 - 2020/12/04

### New

- Fluid and EqFluidJCA now have a 'k' attribute for the wave number
- Fluid have 'K' and 'Z' attributes for the compressibility and impedance

## 0.3.0 - 2020/05/29

### New

- New unified access to rho and c for all media modelled as fluid

## 0.2.0 - 2020/05/26

### New

- new viscoelastic constitutive law
- new resource files: 2 poroelastic, 1 elastic (steel) and 1 rubber

### Changed

- from_yaml can be imported from mediapack directly

## 0.1.0 - 2020/04/21

First dev version.

